Getting Started
========================================================================
Episuite is a suite of tools for epidemiology in Python. It contains
components to handle distributions, delays that can be used to
model and simulate ICU occupation. Episuite also contains client
for modern mobility APIs released in the past year due to the
COVID-19 pandemic.

Below you will find a series of tutorials explaining 

.. toctree::
    :maxdepth: 3

    durations_notebook.ipynb
    icu_admissions_notebook.ipynb
    distributions_notebook.ipynb
    icu_simulation_notebook.ipynb
    prevalence_notebook.ipynb
    symptom_survey.ipynb
    mobility_facebook.ipynb
    mobility_google.ipynb
